@@ -140,7 +140,7 @@ class CatalogAssetAlertsData(List[Any]):
         Transforms catalog data in list form into a dataframe
         :return: Catalog Data
         """
-        return convert_catalog_dtypes(pd.DataFrame(self).explode("constituents"))
+        return convert_catalog_dtypes(pd.DataFrame(self))
 
 
 class CatalogMarketTradesData(List[Any]):
@@ -152,6 +152,36 @@ class CatalogMarketTradesData(List[Any]):
         return convert_catalog_dtypes(pd.DataFrame(self))
 
 
+class CatalogMarketOrderbooksData(List[Any]):
+    def to_dataframe(self, secondary_level: Optional[str] = None) -> DataFrameType:
+        """
+        Transforms catalog data in list form into a dataframe
+        :return: Catalog Data
+        """
+        df_assets = pd.DataFrame(self)
+        if secondary_level is None:
+            pass
+        elif secondary_level == "depths":
+
+            def _assign(x: Any, key: str = "depth") -> Any:
+                try:
+                    return x[key]
+                except TypeError:
+                    return None
+
+            df_assets = df_assets.explode("depths").assign(
+                depth=lambda x: pd.Series(x["depths"])
+            )
+            df_assets["depth"] = df_assets["depths"].apply(_assign, key="depth")
+            df_assets["min_time"] = df_assets["depths"].apply(_assign, key="min_time")
+            df_assets["max_time"] = df_assets["depths"].apply(_assign, key="max_time")
+            df_assets.drop(["depths"], inplace=True, axis=1)
+        else:
+            raise ValueError
+
+        return convert_catalog_dtypes(df_assets)
+
+
 class CatalogAssetPairsData(List[Any]):
     def to_dataframe(self) -> DataFrameType:
         """
@@ -380,6 +410,83 @@ class CatalogMetricsData(List[Any]):
         return convert_catalog_dtypes(df_catalog_metrics)
 
 
+class CatalogExchangeAssetMetricsData(List[Any]):
+    """
+    Transforms catalog exchange asset data in list form into a dataframe
+    :return: Catalog Data
+    """
+
+    def to_dataframe(self) -> DataFrameType:
+        df_catalog_metrics = (
+            pd.DataFrame(self)
+            .explode("frequencies")
+            .assign(
+                frequency=lambda df: _expand_df(
+                    key="frequency", iterable=df.frequencies
+                )
+            )
+            .assign(
+                exchange_asset=lambda df: _expand_df(
+                    key="exchange-assets", iterable=df.frequencies
+                )
+            )
+            .explode("exchange_asset")
+            .drop("frequencies", axis=1)
+            .reset_index(drop=True)
+        )
+        return convert_catalog_dtypes(df_catalog_metrics)
+
+
+class CatalogPairMetricsData(List[Any]):
+    """
+    Transforms catalog pair asset data in list form into a dataframe
+    :return: Catalog Data
+    """
+
+    def to_dataframe(self) -> DataFrameType:
+        df_catalog_metrics = (
+            pd.DataFrame(self)
+            .explode("frequencies")
+            .assign(
+                frequency=lambda df: _expand_df(
+                    key="frequency", iterable=df.frequencies
+                )
+            )
+            .assign(pair=lambda df: _expand_df(key="pairs", iterable=df.frequencies))
+            .explode("pair")
+            .drop("frequencies", axis=1)
+            .reset_index(drop=True)
+        )
+        return convert_catalog_dtypes(df_catalog_metrics)
+
+
+class CatalogInstitutionMetricsData(List[Any]):
+    """
+    Transforms catalog institution asset data in list form into a dataframe
+    :return: Catalog Data
+    """
+
+    def to_dataframe(self) -> DataFrameType:
+        df_catalog_metrics = (
+            pd.DataFrame(self)
+            .explode("frequencies")
+            .assign(
+                frequency=lambda df: _expand_df(
+                    key="frequency", iterable=df.frequencies
+                )
+            )
+            .assign(
+                institution=lambda df: _expand_df(
+                    key="institutions", iterable=df.frequencies
+                )
+            )
+            .explode("institution")
+            .drop("frequencies", axis=1)
+            .reset_index(drop=True)
+        )
+        return convert_catalog_dtypes(df_catalog_metrics)
+
+
 class CatalogMarketMetricsData(List[Any]):
     """
     Transforms catalog data in list form into a dataframe
